@@ -21,9 +21,9 @@ class PreviewAdmin(admin.ModelAdmin):
 
         js = [
             '/static/admin/js/ckeditor/ckeditor.js',
-            '/static/admin/js/ckeditor/config.js',
             '/static/admin/js/ckeditor/start.js',
-        ]
+            '/static/filebrowser/js/FB_CKEditor.js',        
+            ]
 
         css = {
             'ckeditor': ('/static/admin/js/ckeditor/contents.css',),
