@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 
 from ..common.errors import ConfigurationError
-from .models import Site
+from .models import Site, Script
 
 
 def get_site():
@@ -25,3 +25,11 @@ def get_site():
     except Site.MultipleObjectsReturned:
 
         raise ConfigurationError('There is more than one site, please make sure there is exactly one, this feature may be changed in future')
+
+
+def get_scripts():
+    '''
+    Returns all scripts from DB
+    '''
+
+    return Script.objects.all()
